package dao

import (
	"github.com/shopspring/decimal"
	"server/global"
)

type ProjectWorkingHours struct {
	global.GVA_MODEL
	ProjectCode string          `json:"projectCode" form:"projectCode" gorm:"comment:项目编号"`
	People      string          `json:"people" form:"people" gorm:"comment:报工人"`
	Days        float64         `json:"days" form:"days" gorm:"type:double(5,1);not null;comment:天数"`
	Price       decimal.Decimal `json:"price" form:"price" gorm:"type:decimal(10,2);not null;comment:人天单价"`
}

func (ProjectWorkingHours) TableName() string {
	return "project_working_hours"
}

// TODO:工时查询

// QueryWorkingHoursList 查询工时列表
func QueryWorkingHoursList(limit, offset int, code, name string) (projectWorkingHours []ProjectWorkingHours, total int64, err error) {
	// 创建db
	db := global.GVA_DB.Model(&ProjectWorkingHours{}).Where("project_code = ?", code)
	// 如果有条件搜索 下方会自动创建搜索语句
	if name != "" {
		db = db.Where("people LIKE ?", "%"+name+"%")
	}
	err = db.Count(&total).Error
	if err != nil {
		return
	}
	err = db.Order("id desc").Limit(limit).Offset(offset).Find(&projectWorkingHours).Error
	return projectWorkingHours, total, err
}

// QueryWorkingHours 查询工时
func QueryWorkingHours(code string) (workingHours []ProjectWorkingHours, err error) {
	err = global.GVA_DB.Model(&ProjectWorkingHours{}).Where("project_code = ?", code).Find(&workingHours).Error
	return workingHours, err
}

// QueryWorkingHoursByCode 查询单个工时 按id
func QueryWorkingHoursByCode(code string, people string) (workingHours ProjectWorkingHours, err error) {
	err = global.GVA_DB.Model(&ProjectWorkingHours{}).Where("code = ? and people = ?", code, people).First(&workingHours).Error
	return workingHours, err
}

// TODO:工时新增

// CreateWorkingHours 创建工时
func (pwh ProjectWorkingHours) CreateWorkingHours() error {
	return global.GVA_DB.Create(&pwh).Error
}

// TODO:工时修改

// UpdateWorkingHours 修改工时
func (pwh ProjectWorkingHours) UpdateWorkingHours() error {
	return global.GVA_DB.Model(&ProjectWorkingHours{}).Updates(&pwh).Error
}

// TODO:工时删除

// DeleteWorkingHours 删除工时
func (pwh ProjectWorkingHours) DeleteWorkingHours() error {
	return global.GVA_DB.Model(&ProjectWorkingHours{}).Unscoped().Delete(&pwh).Error
}
