package admin

import (
	"server/dao"
	"server/model/common/request"
)

type FinanceService struct{}

func (fs *FinanceService) QueryDailyExpensesList(info request.SearchProject) (list interface{}, total int64, err error) {
	limit := info.PageInfo.PageSize
	offset := info.PageInfo.PageSize * (info.PageInfo.Page - 1)
	dailyExpenses, total, err := dao.QueryDailyExpensesList(limit, offset, info.State, info.Name, info.Time)
	return dailyExpenses, total, err
}

func (fs *FinanceService) QueryDailyExpenses(id int) (dao.DailyExpenses, error) {
	expenses, err := dao.QueryDailyExpenses(id)
	if err != nil {
		return dao.DailyExpenses{}, err
	}
	details, err := dao.QueryDailyFeeDetails(int(expenses.ID))
	if err != nil {
		return dao.DailyExpenses{}, err
	}
	expenses.DailyFeeDetails = details
	return expenses, err
}

func (fs *FinanceService) QueryExpensesGenre() ([]dao.ExpensesGenre, error) {
	return dao.QueryExpensesGenre()
}

func (fs *FinanceService) QueryBorrowingList(info request.SearchProject) (list interface{}, total int64, err error) {
	limit := info.PageInfo.PageSize
	offset := info.PageInfo.PageSize * (info.PageInfo.Page - 1)
	borrowing, total, err := dao.QueryBorrowingList(limit, offset, info.Name, info.Time)
	return borrowing, total, err
}

func (fs *FinanceService) QueryBorrowing(id int) (dao.Borrowing, error) {
	return dao.QueryBorrowing(id)
}

func (fs *FinanceService) QueryDailyFileList(info request.SearchIdNameGenre) (list interface{}, total int64, err error) {
	limit := info.PageInfo.PageSize
	offset := info.PageInfo.PageSize * (info.PageInfo.Page - 1)
	dailyFiles, total, err := dao.QueryDailyFileList(limit, offset, info.Id, info.Genre, info.Name)
	return dailyFiles, total, err
}

func (fs *FinanceService) QueryProjectFinance(code string) (dao.Project, error) {
	project, err := dao.QueryProjectByCode(code)
	if err != nil {
		return dao.Project{}, err
	}
	collection, err := dao.QueryCollection(code)
	if err != nil {
		return dao.Project{}, err
	}
	workingHours, err := dao.QueryWorkingHours(code)
	if err != nil {
		return dao.Project{}, err
	}
	reimbursements, err := dao.QueryReimbursement(code)
	if err != nil {
		return dao.Project{}, err
	}
	for i, reimbursement := range reimbursements {
		details, err := dao.QueryFeeDetails(int(reimbursement.ID))
		if err != nil {
			return dao.Project{}, err
		}
		reimbursements[i].FeeDetails = details
	}
	project.Collection = collection
	project.WorkingHours = workingHours
	project.Reimbursement = reimbursements

	return project, err
}

func (fs *FinanceService) CreateDailyExpenses(expenses dao.DailyExpenses) error {
	return expenses.CreateDailyExpenses()
}

func (fs *FinanceService) CreateExpensesGenre(genre dao.ExpensesGenre) error {
	return genre.CreateExpensesGenre()
}

func (fs *FinanceService) CreateBorrowing(borrowing dao.Borrowing) error {
	return borrowing.CreateBorrowing()
}

func (fs *FinanceService) CreateDailyFile(file dao.DailyFile) error {
	return file.CreateDailyFile()
}

func (fs *FinanceService) UpdateDailyExpenses(expenses dao.DailyExpenses) error {
	return expenses.UpdateDailyExpenses()
}

func (fs *FinanceService) UpdateExpensesGenre(genre dao.ExpensesGenre) error {
	return genre.UpdateExpensesGenre()
}

func (fs *FinanceService) UpdateBorrowing(borrowing dao.Borrowing) error {
	return borrowing.UpdateBorrowing()
}

func (fs *FinanceService) DeleteDailyExpenses(expenses dao.DailyExpenses) error {
	return expenses.DeleteDailyExpenses()
}

func (fs *FinanceService) DeleteExpensesGenre(genre dao.ExpensesGenre) error {
	return genre.DeleteExpensesGenre()
}

func (fs *FinanceService) DeleteBorrowing(borrowing dao.Borrowing) error {
	return borrowing.DeleteBorrowing()
}

func (fs *FinanceService) DeleteDailyFile(file dao.DailyFile) error {
	return file.DeleteDailyFile()
}
